==> theme-1.0.3.zip: adw/functions.php <==
<?php
namespace adw;
use YahnisElsts\PluginUpdateChecker\v5\PucFactory;

require 'plugin-update-checker-5.1/plugin-update-checker.php';

class Theme
{
    public static function init()
    {
        $myUpdateChecker = PucFactory::buildUpdateChecker(
	        'http://theme.helloapplied.com/theme.json',
	        __FILE__,
	        'adw'
        );

        add_action( 'init', ['adw\Theme', 'register_acf_blocks']);
        add_action('wp_enqueue_scripts', function(){
            self::enqueueStyles();
            self::enqueueScripts();
            });

        if(is_admin()) {
            add_editor_style('css/build/style.css');
            add_theme_support('editor-styles');
        }
    }

    public static function register_acf_blocks() {
        register_block_type( __DIR__ . '/blocks/project-info');
        register_block_type( __DIR__ . '/blocks/project-block-link');
        register_block_type( __DIR__ . '/blocks/carousel');
        register_block_type( __DIR__ . '/blocks/carousel-slide');
    }

    public static function getVersion()
    {
        // Get the theme info so that we can use the version in script and link tags
        $theme = wp_get_theme();
        return $theme->get('Version');
    }

    public static function enqueueStyles() {
        if(!is_admin()) {
            wp_enqueue_style(
                'adw-styles',
                get_stylesheet_directory_uri().'/css/build/style.css',
                null,
                self::getVersion()
                );
        }
    }

    public static function enqueueScripts() {
        wp_enqueue_script(
            'slick-nav',
            get_stylesheet_directory_uri() . '/js/jquery.slicknav.min.js',
            ['jquery'],
            '1.0.10',
            false);
        wp_enqueue_script(
            'slick-slider',
            get_stylesheet_directory_uri() . '/js/slick.min.js',
            ['jquery'],
            '1.5.9',
            false);
        wp_enqueue_script(
            'main-script',
            get_stylesheet_directory_uri() . '/js/main.js',
            ['jquery'],
            self::getVersion(),
            true);
    }
}

Theme::init();

==> theme-1.0.4.zip: adw/functions.php <==
<?php
namespace adw;
use YahnisElsts\PluginUpdateChecker\v5\PucFactory;

require 'plugin-update-checker-5.1/plugin-update-checker.php';

class Theme
{
    public static function init()
    {
        $myUpdateChecker = PucFactory::buildUpdateChecker(
	        'http://theme.helloapplied.com/theme.json',
	        __FILE__,
	        'adw'
        );

        add_action( 'init', ['adw\Theme', 'register_acf_blocks']);
        add_action('wp_enqueue_scripts', function(){
            self::enqueueStyles();
            self::enqueueScripts();
            });

        //if(is_admin()) {
        //    add_editor_style('css/build/style.css');
        //    add_theme_support('editor-styles');
        //}
    }

    public static function register_acf_blocks() {
        register_block_type( __DIR__ . '/blocks/article-card-link');
        register_block_type( __DIR__ . '/blocks/project-list');
        register_block_type( __DIR__ . '/blocks/project-info');
        register_block_type( __DIR__ . '/blocks/project-block-link');
        register_block_type( __DIR__ . '/blocks/carousel');
        register_block_type( __DIR__ . '/blocks/carousel-slide');
    }

    public static function getVersion()
    {
        // Get the theme info so that we can use the version in script and link tags
        $theme = wp_get_theme();
        return $theme->get('Version');
    }

    public static function enqueueStyles() {
        if(!is_admin()) {
            wp_enqueue_style(
                'adw-styles',
                get_stylesheet_directory_uri().'/css/build/style.css',
                null,
                self::getVersion()
                );
        }
    }

    public static function enqueueScripts() {
        wp_enqueue_script(
            'slick-nav',
            get_stylesheet_directory_uri() . '/js/jquery.slicknav.min.js',
            ['jquery'],
            '1.0.10',
            false);
        wp_enqueue_script(
            'slick-slider',
            get_stylesheet_directory_uri() . '/js/slick.min.js',
            ['jquery'],
            '1.5.9',
            false);
        wp_enqueue_script(
            'main-script',
            get_stylesheet_directory_uri() . '/js/main.js',
            ['jquery'],
            self::getVersion(),
            true);
    }
}

Theme::init();
